@@ -1,6 +1,6 @@
 use strict; use warnings;
 package XXX;
-our $VERSION = '0.35';
+our $VERSION = '0.36';
 use base 'Exporter';
 
 our @EXPORT = qw( WWW XXX YYY ZZZ );
@@ -25,6 +25,12 @@ sub import {
         }
         last;
     }
+    if (grep /^-?global$/, @args) {
+        *main::WWW = \&WWW;
+        *main::XXX = \&XXX;
+        *main::YYY = \&YYY;
+        *main::ZZZ = \&ZZZ;
+    }
     @_ = ($package);
     goto &Exporter::import;
 }
